.. _community:

Community
=========

DebOps has a small but active community of developers and users. Come on in and
say hi!

DebOps monorepo
---------------

Main development of the project is done in its :command:`git` monorepo, using
a distributed development model. The default location of the monorepo is the
`DebOps GitHub repository`__, used for the issues and pull requests. There's
also a `read-only mirror on GitLab`__ used to manage the public test pipeline
based on `GitLab CI`__.

The developers and users maintain their own `monorepo forks`__ on GitHub, used
for development and pull requests.

.. __: https://github.com/debops/debops/
.. __: https://gitlab.com/debops/debops/
.. __: https://about.gitlab.com/product/continuous-integration/
.. __: https://github.com/debops/debops/network/members


IRC channel
-----------

The official ``#debops`` IRC channel is located on the `FreeNode`__ IRC
network. You can use it to chat in real time about DebOps, get help with any
pressing issues and compare notes with other DebOps users.

.. __: https://freenode.net/


Mailing list
------------

The DebOps project has `its own mailing list`__, ``debops-users``, based on
Mailman. The list has low traffic and is used for notifications about
significant changes in the project, and more asynchronous communication. You
can also check out the `mailing list archives`__.

.. __: https://lists.debops.org/mailman/listinfo/
.. __: https://lists.debops.org/pipermail/debops-users/
